summaryrefslogtreecommitdiff
path: root/contrib/fhttp/fhttp.go
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/fhttp/fhttp.go')
-rw-r--r--contrib/fhttp/fhttp.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/contrib/fhttp/fhttp.go b/contrib/fhttp/fhttp.go
index cf13b25..8887fbc 100644
--- a/contrib/fhttp/fhttp.go
+++ b/contrib/fhttp/fhttp.go
@@ -5,10 +5,10 @@ import (
"net/http"
)
// RegisterRemoteImage registers a remote image. Downloading the image from the
// provided URL and adding it to the PDF but not adding it to the page. Use
// Image() with the same URL to add the image to the page.
-func RegisterRemoteImage(f *gofpdf.Fpdf, urlStr, tp string) (info *gofpdf.ImageInfoType) {
+func RegisterHttpImage(f *gofpdf.Fpdf, urlStr, tp string) (info *gofpdf.ImageInfoType) {
info = f.GetImageInfo(urlStr)
if info != nil {
@@ -5,10 +5,10 @@ import (
"net/http"
)
-// RegisterRemoteImage registers a remote image. Downloading the image from the
+// RegisterHttpImage registers a HTTP image. Downloading the image from the
// provided URL and adding it to the PDF but not adding it to the page. Use
// Image() with the same URL to add the image to the page.